pub struct EpochBoundaries(/* private fields */);Expand description
Stores the epoch boundaries.
The representation stored is a map between the epoch and the sequence number of the respective last checkpoint.
Examples
let boundaries: EpochBoundaries = [(0, 5), (1, 100), (2, 1000)].into_iter().collect();
assert_eq!(boundaries.get(1), Some(100));
// The last checkpoints of a range of epochs, in epoch order.
assert_eq!(
boundaries.range(..2).collect::<Vec<_>>(),
vec![(0, 5), (1, 100)]
);Implementations
Sourceimpl EpochBoundaries
impl EpochBoundaries
Sourcepub fn get(&self, epoch: EpochId) -> Option<CheckpointSequenceNumber>
pub fn get(&self, epoch: EpochId) -> Option<CheckpointSequenceNumber>
Returns the boundary of the given epoch.
Sourcepub fn range(
&self,
range: impl RangeBounds<EpochId>,
) -> impl Iterator<Item = (EpochId, CheckpointSequenceNumber)> + '_
pub fn range( &self, range: impl RangeBounds<EpochId>, ) -> impl Iterator<Item = (EpochId, CheckpointSequenceNumber)> + '_
Returns the recorded (epoch, last checkpoint) pairs for the epochs in
range, in epoch order.
Sourcepub fn contains(&self, epoch: EpochId) -> bool
pub fn contains(&self, epoch: EpochId) -> bool
Returns whether the given epoch has a recorded boundary.
Sourcepub fn insert_next(
&mut self,
epoch: EpochId,
boundary: CheckpointSequenceNumber,
) -> Result<()>
pub fn insert_next( &mut self, epoch: EpochId, boundary: CheckpointSequenceNumber, ) -> Result<()>
Inserts a new epoch boundary, keeping the recorded epochs contiguous. Any existing boundary for the same epoch is overwritten.
Errors
Fails if the previous epoch has not been already recorded.